function [x,cvg] = DampedNewton(x,F,DF,q,tol)
% MATLAB function for the damped Newton method
cvg = [];
A = feval(DF,x);
s = A\feval(F,x);
xn = x-s;
lambda = 1;
while (norm(s) > tol)
    st = A\feval(F,xn);
    while (norm(st) > (1-lambda/2)*norm(s))
        lambda = q*lambda;
        if ((lambda < 0.001) || (size(cvg,1) > 25))
            cvg = [];
            disp('DAMPED NEWTON: Failure of convergence');
            return;
        end
        xn = x-lambda*s;
        st = A\feval(F,xn);
    end
    cvg = [cvg; lambda, norm(xn) , log(norm(xn)), norm(feval(F,xn))];
    x = xn;
    A = feval(DF,x);
    s = A\feval(F,x);
    lambda = min(lambda/q,1);
    xn = x-lambda*s;
end
cvg = [cvg; lambda, norm(xn) , log(norm(xn)), ...
    norm(feval(F,xn))];
x = xn;